@@ -15,14 +15,12 @@ TranscribeAsyncFileStatus = speech_service_pb2.TranscribeAsyncFileStatus
 
 SpeechServiceStub = speech_service_pb2_grpc.SpeechServiceStub
 
-_CERTS_FILE = os.path.realpath(os.path.join(os.path.dirname(__file__), "roots.pem"))
 _API_HOST = ""
 _API_KEY = ""
 _DEFAULT_API_HOST = "https://api.soniox.com:443"
 
 
-with open(_CERTS_FILE, "rb") as fh:
-    _CREDENTIALS = grpc.ssl_channel_credentials(fh.read())
+_CREDENTIALS = grpc.ssl_channel_credentials()
 
 
 def set_api_host(api_host: str) -> None:
@@ -57,7 +55,11 @@ def get_api_key(api_key: Optional[str]) -> str:
     if api_key == "":
         api_key = os.getenv("SONIOX_API_KEY", default="")
     if api_key == "":
-        raise Exception("Soniox API key not set. Please set it using soniox.service.set_api_key().")
+        raise Exception(
+            "Soniox API key not specified. Please specify it using the SONIOX_API_KEY "
+            "environment variable, by calling soniox.speech_service.set_api_key(), "
+            "or by passing the api_key parameter to the SpeechService() constructor."
+        )
     return api_key
 
 
@@ -72,7 +74,7 @@ def create_channel(api_host: Optional[str]) -> grpc.Channel:
         return grpc.insecure_channel(api_host)
 
 
-class Client:
+class SpeechClient:
     def __init__(self, api_host: Optional[str] = None, api_key: Optional[str] = None) -> None:
         self._channel = create_channel(api_host)
         try:
@@ -85,7 +87,7 @@ class Client:
     def close(self) -> None:
         self._channel.close()
 
-    def __enter__(self) -> "Client":
+    def __enter__(self) -> "SpeechClient":
         return self
 
     def __exit__(self, exc_type, exc_value, traceback) -> None:
@@ -162,7 +164,7 @@ class Client:
                 raise e from iter_exception
             raise
 
-    def TranscribeStreamFile(
+    def TranscribeCompleteStream(
         self, config: TranscriptionConfig, iter_audio: Iterable[bytes]
     ) -> Union[Result, List[Result]]:
         assert not config.include_nonfinal
@@ -279,7 +281,7 @@ class Client:
         response = self._client.GetTranscribeAsyncStatus(request)
 
         if len(response.files) != 1:
-            raise Exception(f"Unexpected number of files returned.")
+            raise Exception("Unexpected number of files returned.")
 
         return response.files[0]
 
@@ -355,3 +357,7 @@ def update_result(result: Result, new_result: Result) -> None:
     result.total_proc_time_ms = new_result.total_proc_time_ms
     del result.speakers[:]
     result.speakers.extend(new_result.speakers)
+
+
+# For backward compatibility.
+Client = SpeechClient
